@@ -19,42 +19,7 @@
 // along with this library; if not, write to the Free Software Foundation, 
 // Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA 
 
-#include "Rcpp.h"
-
-RcppParams::RcppParams(SEXP params) {
-    if (!Rf_isNewList(params))
-	throw std::range_error("RcppParams: non-list passed to constructor");
-    int len = Rf_length(params);
-    SEXP names = Rf_getAttrib(params, R_NamesSymbol);
-    if (names == R_NilValue)
-	throw std::range_error("RcppParams: list must have named elements");
-    for (int i = 0; i < len; i++) {
-	std::string nm = std::string(CHAR(STRING_ELT(names,i)));
-	if (nm.size() == 0)
-	    throw std::range_error("RcppParams: all list elements must be named");
-	pmap[nm] = i;
-    }
-    _params = params;
-}
-
-void RcppParams::checkNames(char *inputNames[], int len) {
-    for (int i = 0; i < len; i++) {
-	std::map<std::string,int>::iterator iter = pmap.find(inputNames[i]);
-	if (iter == pmap.end()) {
-	    std::string mesg = "RcppParams::checkNames: missing required parameter ";
-	    throw std::range_error(mesg+inputNames[i]);
-	}
-    }
-}
-
-bool RcppParams::exists(std::string name) {
-    bool rc = true;
-    std::map<std::string,int>::iterator iter = pmap.find(name);
-    if (iter == pmap.end()) {
-	rc = false;
-    }
-    return rc;
-}
+#include <Rcpp.h>
 
 RcppFrame::RcppFrame(SEXP df) {
     if (!Rf_isNewList(df))
@@ -129,131 +94,6 @@ RcppFrame::RcppFrame(SEXP df) {
     }
 }
 
-double RcppParams::getDoubleValue(std::string name) {
-    std::map<std::string,int>::iterator iter = pmap.find(name);
-    if (iter == pmap.end()) {
-	std::string mesg = "RcppParams::getDoubleValue: no such name: ";
-	throw std::range_error(mesg+name);
-    }
-    int posn = iter->second;
-    SEXP elt = VECTOR_ELT(_params,posn);
-    if (!Rf_isNumeric(elt) || Rf_length(elt) != 1) {
-	std::string mesg = "RcppParams::getDoubleValue: must be scalar ";
-	throw std::range_error(mesg+name);
-    }
-    if (Rf_isInteger(elt))
-	return (double)INTEGER(elt)[0];
-    else if (Rf_isReal(elt))
-	return REAL(elt)[0];
-    else {
-	std::string mesg = "RcppParams::getDoubleValue: invalid value for ";
-	throw std::range_error(mesg+name);
-    }
-    return 0; // never get here
-}
-
-int RcppParams::getIntValue(std::string name) {
-    std::map<std::string,int>::iterator iter = pmap.find(name);
-    if (iter == pmap.end()) {
-	std::string mesg = "RcppParams::getIntValue: no such name: ";
-	throw std::range_error(mesg+name);
-    }
-    int posn = iter->second;
-    SEXP elt = VECTOR_ELT(_params,posn);
-    if (!Rf_isNumeric(elt) || Rf_length(elt) != 1) {
-	std::string mesg = "RcppParams::getIntValue: must be scalar: ";
-	throw std::range_error(mesg+name);
-    }
-    if (Rf_isInteger(elt))
-	return INTEGER(elt)[0];
-    else if (Rf_isReal(elt))
-	return (int)REAL(elt)[0];
-    else {
-	std::string mesg = "RcppParams::getIntValue: invalid value for: ";
-	throw std::range_error(mesg+name);
-    }
-    return 0; // never get here
-}
-
-bool RcppParams::getBoolValue(std::string name) {
-    std::map<std::string,int>::iterator iter = pmap.find(name);
-    if (iter == pmap.end()) {
-	std::string mesg = "RcppParams::getBoolValue: no such name: ";
-	throw std::range_error(mesg+name);
-    }
-    int posn = iter->second;
-    SEXP elt = VECTOR_ELT(_params,posn);
-    if (Rf_isLogical(elt))
-	return INTEGER(elt)[0];
-    else {
-	std::string mesg = "RcppParams::getBoolValue: invalid value for: ";
-	throw std::range_error(mesg+name);
-    }
-    return false; // never get here
-}
-
-std::string RcppParams::getStringValue(std::string name) {
-    std::map<std::string,int>::iterator iter = pmap.find(name);
-    if (iter == pmap.end()) {
-	std::string mesg = "RcppParams::getStringValue: no such name: ";
-	throw std::range_error(mesg+name);
-    }
-    int posn = iter->second;
-    SEXP elt = VECTOR_ELT(_params,posn);
-    if (Rf_isString(elt))
-		return std::string(CHAR(STRING_ELT(elt,0)));
-    else {
-	std::string mesg = "RcppParams::getStringValue: invalid value for: ";
-	throw std::range_error(mesg+name);
-    }
-    return ""; // never get here
-}
-
-RcppDate RcppParams::getDateValue(std::string name) {
-    std::map<std::string,int>::iterator iter = pmap.find(name);
-    if (iter == pmap.end()) {
-	std::string mesg = "RcppParams::getDateValue: no such name: ";
-	throw std::range_error(mesg+name);
-    }
-    int posn = iter->second;
-    SEXP elt = VECTOR_ELT(_params,posn);
-    if (!Rf_isNumeric(elt) || Rf_length(elt) != 1) {
-	std::string mesg = "RcppParams::getDateValue: invalide date: ";
-	throw std::range_error(mesg+name);
-    }
-
-    int d;
-    if (Rf_isReal(elt)) // R stores julian value in a double.
-	d = (int)REAL(elt)[0];
-    else {
-	std::string mesg = "RcppParams::getDateValue: invalid value for: ";
-	throw std::range_error(mesg+name);
-    }
-    return RcppDate(d);
-}
-
-RcppDatetime RcppParams::getDatetimeValue(std::string name) {
-    std::map<std::string,int>::iterator iter = pmap.find(name);
-    if (iter == pmap.end()) {
-        std::string mesg = "RcppParams::getDatetimeValue: no such name: ";
-	throw std::range_error(mesg+name);
-    }
-    int posn = iter->second;
-    SEXP elt = VECTOR_ELT(_params, posn);
-    if (!Rf_isNumeric(elt) || Rf_length(elt) != 1) {
-	std::string mesg = "RcppParams::getDateValue: invalide date: ";
-	throw std::range_error(mesg+name);
-    }
-    double d;
-    if (Rf_isReal(elt)) 	// R stores POSIXt as a double
-	d = REAL(elt)[0];
-    else {
-	std::string mesg = "RcppParams::getDatetimeValue: invalid value for: ";
-	throw std::range_error(mesg+name);
-    }
-    return RcppDatetime(d);
-}
-
 RcppDateVector::RcppDateVector(SEXP vec) {
     int i;
     if (!Rf_isNumeric(vec) || Rf_isMatrix(vec) || Rf_isLogical(vec))
@@ -800,94 +640,6 @@ SEXP RcppResultSet::getReturnList() {
     return rl;
 }
 
-// Print an RcppDate.
-std::ostream& operator<<(std::ostream& os, const RcppDate& date) {
-    os << date.getYear() << "-" << date.getMonth() << "-" << date.getDay();
-    return os;
-}
-
-// A few basic date operations.
-RcppDate operator+(const RcppDate& date, int offset) {
-    RcppDate temp(date.month, date.day, date.year);
-    temp.jdn += offset;
-    temp.jdn2mdy();
-    return temp;
-}
-
-int operator-(const RcppDate& date2, const RcppDate& date1) {
-    return date2.jdn - date1.jdn;
-}
-
-bool  operator<(const RcppDate &date1, const RcppDate& date2) {
-    return date1.jdn < date2.jdn;
-}
-
-bool  operator>(const RcppDate &date1, const RcppDate& date2) {
-    return date1.jdn > date2.jdn;
-}
-
-bool  operator>=(const RcppDate &date1, const RcppDate& date2) {
-    return date1.jdn >= date2.jdn;
-}
-
-bool  operator<=(const RcppDate &date1, const RcppDate& date2) {
-    return date1.jdn <= date2.jdn;
-}
-
-bool  operator==(const RcppDate &date1, const RcppDate& date2) {
-    return date1.jdn == date2.jdn;
-}
-
-// Offset used to convert from R date representation to Julian day number.
-const int RcppDate::Jan1970Offset = 2440588;
-
-// Offset used to convert between R / Unix date of Jan 1, 1970 and the QL base date
-const int RcppDate::QLtoJan1970Offset = 25569; 
-
-// The Julian day number (jdn) is the number of days since Monday,
-// Jan 1, 4713BC (year = -4712). Here 1BC is year 0, 2BC is year -1, etc.
-// On the other hand, R measures days since Jan 1, 1970, and these dates are
-// converted to jdn's by adding Jan1970Offset.
-//
-// mdy2jdn and jdn2mdy are inverse functions for dates back to 
-// year = -4799 (4800BC).
-//
-// See the Wikipedia entry on Julian day number for more information 
-// on these algorithms.
-//
-
-// Transform month/day/year to Julian day number.
-void RcppDate::mdy2jdn() {
-    int m = month, d = day, y = year;
-    int a = (14 - m)/12;
-    y += 4800 - a;
-    m += 12*a - 3;
-    jdn = (d + (153*m + 2)/5 + 365*y
-	   + y/4 - y/100 + y/400 - 32045);
-}
-
-// Transform from Julian day number to month/day/year.
-void RcppDate::jdn2mdy() {
-    int jul = jdn + 32044;
-    int g = jul/146097;
-    int dg = jul % 146097;
-    int c = (dg/36524 + 1)*3/4;
-    int dc = dg - c*36524;
-    int b = dc/1461;
-    int db = dc % 1461;
-    int a = (db/365 + 1)*3/4;
-    int da = db - a*365;
-    int y = g*400 + c*100 + b*4 + a;
-    int m = (da*5 + 308)/153 - 2;
-    int d = da - (m + 4)*153 /5 + 122;
-    y = y - 4800 + (m + 2)/12;
-    m = (m + 2) % 12 + 1;
-    d = d + 1;
-    month = m;
-    day   = d;
-    year  = y;
-}
-
 SEXP RcppFunction::listCall() {
     if (names.size() != (unsigned)listSize)
 	throw std::range_error("RcppFunction::listCall: no. of names != no. of items");
