@@ -22,147 +22,11 @@
 #ifndef Rcpp_hpp
 #define Rcpp_hpp
 
-#include <iostream>
-#include <sstream>
-#include <string>
-#include <list>
-#include <map>
-#include <stdexcept>
-#include <vector>
-
-// include R headers, but set R_NO_REMAP and access everything via Rf_ prefixes
-#define R_NO_REMAP
-
-#include <R.h>
-#include <Rinternals.h>
-
+#include <RcppCommon.h>
+#include <RcppDate.h>
+#include <RcppDatetime.h>
 #include <RcppList.h>
-
-// #ifdef BUILDING_DLL
-// #define RcppExport extern "C" __declspec(dllexport)
-// #else
-#define RcppExport extern "C"
-// #endif
-
-char *copyMessageToR(const char* const mesg);
-
-class RcppDate {
-private:
-    void mdy2jdn(); // month/day/year to Julian day number.
-    void jdn2mdy(); // Julian day number to month/day/year.
-    int month, day, year;
-    int jdn; // Julian day number
-
-public:
-    static const int Jan1970Offset;	// offset between Jan 1, 1970 and Julian Day Number
-    static const int QLtoJan1970Offset;	// offset between Jan 1, 1970 and QuantLib BaseDate
-    RcppDate() { month=1, day=1, year=1970; mdy2jdn(); }
-    RcppDate(int Rjdn) { jdn = Rjdn+Jan1970Offset; jdn2mdy(); }
-    RcppDate(int month_, int day_, int year_) : month(month_), 
-						day(day_),
-						year(year_) { 
-        if (month < 1 || month > 12 || day < 1 || day > 31)
-	    throw std::range_error("RcppDate: invalid date");
-        mdy2jdn();
-    }
-    int getMonth() const { return month; }
-    int getDay()  const  { return day; }
-    int getYear() const  { return year; }
-    int getJDN()  const  { return jdn; }
-
-    // Minimal set of date operations.
-
-    // These operators tend to conflict with QuantLib's
-    friend RcppDate operator+(const RcppDate &date, int offset);
-    friend int      operator-(const RcppDate& date1, const RcppDate& date2);
-    friend bool     operator<(const RcppDate &date1, const RcppDate& date2);
-    friend bool     operator>(const RcppDate &date1, const RcppDate& date2);
-    friend bool     operator==(const RcppDate &date1, const RcppDate& date2);
-    friend bool     operator>=(const RcppDate &date1, const RcppDate& date2);
-    friend bool     operator<=(const RcppDate &date1, const RcppDate& date2);
-
-    friend std::ostream& operator<<(std::ostream& os, const RcppDate& date);
-// #ifdef USING_QUANTLIB
-//     // Conversions from/to a QuantLib Date.
-//     RcppDate(Date dateQL);
-//     operator Date() const;
-// #endif
-};
-
-class RcppDatetime {
-private:
-    double m_d;
-    bool m_parsed;
-    int m_us;					// microseconds giving us fractional seconds
-    struct tm m_tm;
-    void parseTime() {
-	time_t tt = static_cast<time_t>(floor(m_d));		// time_t is the nb of seconds, ignore the fractional microseconds
-	m_us = static_cast<int>(round( (m_d - tt) * 1.0e6));	// fractional (micro)secs is diff. between (fractional) m_d and m_tt
-	m_tm = *localtime(&tt);			// parse time type into time structure 
-	m_parsed = true;			// and note that we parsed the time type
-	//printf("Time is %s %20u %8u\n", ctime(&m_tt), (unsigned int) m_tt, m_us);
-    };
-
-protected:
-    //friend class RcppResultSet;
-    friend class ColDatum;
-    //friend class RcppFunction;
-
-public:
-    RcppDatetime(void) : m_d(0), m_parsed(false), m_us(0) { };
-    RcppDatetime(const double d) : m_d(d), m_parsed(false), m_us(0) { };
-
-    double getFractionalTimestamp(void) const { return m_d; }
-
-    int getYear(void)     { if (!m_parsed) parseTime(); return m_tm.tm_year + 1900; }
-    int getMonth(void)    { if (!m_parsed) parseTime(); return m_tm.tm_mon + 1; }
-    int getDay(void)      { if (!m_parsed) parseTime(); return m_tm.tm_mday; } 
-    int getWeekday(void)  { if (!m_parsed) parseTime(); return m_tm.tm_wday; } 
-    int getHour(void)     { if (!m_parsed) parseTime(); return m_tm.tm_hour; } 
-    int getMinute(void)   { if (!m_parsed) parseTime(); return m_tm.tm_min; } 
-    int getSecond(void)   { if (!m_parsed) parseTime(); return m_tm.tm_sec; } 
-    int getMicroSec(void) { if (!m_parsed) parseTime(); return m_us; } 
-
-    friend RcppDatetime operator+(const RcppDatetime &date,   double offset) {
-	RcppDatetime tmp(date.m_d);
-	tmp.m_d += offset;
-	tmp.m_parsed = false;
-	return tmp;
-    }
-    friend double       operator-(const RcppDatetime& dt1,  const RcppDatetime& dt2) { return dt2.m_d -  dt1.m_d; }
-    friend bool         operator<(const RcppDatetime &dt1,  const RcppDatetime& dt2) { return dt1.m_d <  dt2.m_d; }
-    friend bool         operator<=(const RcppDatetime &dt1, const RcppDatetime& dt2) { return dt1.m_d <= dt2.m_d; }
-    friend bool         operator>(const RcppDatetime &dt1,  const RcppDatetime& dt2) { return dt1.m_d >  dt2.m_d; }
-    friend bool         operator>=(const RcppDatetime &dt1, const RcppDatetime& dt2) { return dt1.m_d >= dt2.m_d; }
-    friend bool         operator==(const RcppDatetime &dt1, const RcppDatetime& dt2) { return dt1.m_d == dt2.m_d; }  // remember float math...
-
-    friend std::ostream& operator<<(std::ostream& os, const RcppDatetime &datetime) {
-	RcppDatetime dt(datetime);
-	dt.parseTime();
-	char buf[32], usec[16];
-	strftime(buf, 31, "%Y-%m-%d %H:%M:%S", &dt.m_tm);
-	snprintf(usec, 15, ".%.06d", dt.m_us);
-	os << buf << usec;
-	return os;
-    }
-
-};
-
-class RcppParams {
-public:
-    RcppParams(SEXP params);
-    void   	checkNames(char *inputNames[], int len);
-    bool	exists(std::string name);
-    double 	getDoubleValue(std::string name);
-    int    	getIntValue(std::string name);
-    std::string getStringValue(std::string name);
-    bool   	getBoolValue(std::string name);
-    RcppDate 	getDateValue(std::string name);
-    RcppDatetime getDatetimeValue(std::string name);
-private:
-    std::map<std::string, int> pmap;
-    SEXP _params;
-};
+#include <RcppParams.h>
 
 // Supported data frame column types.
 enum ColType { COLTYPE_DOUBLE, COLTYPE_INT, COLTYPE_STRING,
